@@ -1,4 +1,3 @@
-
 from __future__ import print_function
 import numpy as np
 from pydub import AudioSegment
@@ -13,6 +12,7 @@ parser.add_argument('--inX', action='store', type=str, required=True)
 parser.add_argument('--inY', action='store', type=str, required=True)
 parser.add_argument('--epochs', action='store', type=int, required=True)
 parser.add_argument('--tx', action='store', type=int, default=5511)
+parser.add_argument('--bsize', action='store', type=int, default=10)
 parser.add_argument('--nf', action='store', type=int, default=101)
 parser.add_argument('--ty', action='store', type=int, default=1375)
 args = parser.parse_args()
@@ -58,7 +58,10 @@ X_train,X_test,Y_train,Y_test = train_test_split(X,Y,test_size=0.2,random_state=
 from tensorflow.keras.models import Model
 from tensorflow.keras.layers import Dense, Activation, Dropout, Input, TimeDistributed, Conv1D
 from tensorflow.keras.layers import GRU, BatchNormalization
-from tensorflow.keras.optimizers import Adam
+try:
+    from tensorflow.keras.optimizers.legacy import Adam
+except:
+    from tensorflow.keras.optimizers import Adam
 
 
 
@@ -118,15 +121,15 @@ model.compile(loss='binary_crossentropy', optimizer=opt, metrics=["accuracy"])
 
 epoch = args.epochs
 
-model.fit(X,Y,batch_size=10,epochs=epoch)
+model.fit(X,Y,batch_size=args.bsize,epochs=epoch)
 
-while True:
-    print("Wanna train more!! (y/n)")
-    ch = input('>> ')
-    if ch == 'y':
-        model.fit(X,Y,batch_size=5,epochs=5)
-    else:
-        break
+# while True:
+#     print("Wanna train more!! (y/n)")
+#     ch = input('>> ')
+#     if ch == 'y':
+#         model.fit(X,Y,batch_size=5,epochs=5)
+#     else:
+#         break
  
 model.save("model.h5")
 print("Model Saved !")
